# Overview

This document contains a list of maintainers in this repo.

## Current Maintainers

| Maintainer     | GitHub ID                                 | Affiliation           |
| -------------- | ----------------------------------------- | --------------------- |
| Claus Seibold  | [csSei](https://github.com/csSei)         | Ingenics Digital GmbH |
| David Kauschke | [kauschked](https://github.com/kauschked) | Ingenics Digital GmbH |
